@@ -36,9 +36,13 @@ logging.basicConfig(
             "%(message)s"))
 
 
-@pytest.fixture(scope="module")
-def srv():
-    cfg = config.load(["test/conf/daemon.conf"])
+@pytest.fixture(
+    scope="module",
+    params=["daemon", "proxy"]
+)
+def srv(request):
+    path = "test/conf/{}.conf".format(request.param)
+    cfg = config.load(path)
     s = server.Server(cfg)
     s.start()
     yield s
@@ -46,19 +50,19 @@ def srv():
 
 
 def test_method_not_allowed(srv):
-    with http.UnixClient(srv.config.control.socket) as c:
+    with http.ControlClient(srv.config) as c:
         res = c.request("NO_SUCH_METHO", "/tickets/")
         assert res.status == http_client.METHOD_NOT_ALLOWED
 
 
 def test_no_resource(srv):
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("GET", "/no/such/resource")
+    with http.ControlClient(srv.config) as c:
+        res = c.get("/no/such/resource")
         assert res.status == 404
 
 
 def test_no_method(srv):
-    with http.UnixClient(srv.config.control.socket) as c:
+    with http.ControlClient(srv.config) as c:
         res = c.request("FOO", "/tickets/")
         assert res.status == 405
 
@@ -68,8 +72,8 @@ def test_get(srv, fake_time):
         ops=["read"], sparse=False, dirty=False, transfer_id="123")
     srv.auth.add(ticket)
     fake_time.now += 200
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("GET", "/tickets/%(uuid)s" % ticket)
+    with http.ControlClient(srv.config) as c:
+        res = c.get("/tickets/%(uuid)s" % ticket)
         assert res.status == 200
         server_ticket = json.loads(res.read())
         # The server adds an expires key
@@ -81,16 +85,16 @@ def test_get(srv, fake_time):
 
 
 def test_get_not_found(srv):
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("GET", "/tickets/%s" % uuid.uuid4())
+    with http.ControlClient(srv.config) as c:
+        res = c.get("/tickets/%s" % uuid.uuid4())
         assert res.status == 404
 
 
 def test_put(srv, fake_time):
     ticket = testutil.create_ticket(sparse=False, dirty=False)
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, body)
         # Server adds expires key
         ticket["expires"] = int(util.monotonic_time()) + ticket["timeout"]
         ticket["active"] = False
@@ -104,8 +108,8 @@ def test_put(srv, fake_time):
 def test_put_bad_url_value(srv, fake_time):
     ticket = testutil.create_ticket(url='http://[1.2.3.4:33')
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
@@ -114,8 +118,8 @@ def test_general_exception(srv, monkeypatch):
     def fail(*a, **kw):
         raise Exception("SECRET")
     monkeypatch.setattr(tickets.Handler, "get", fail)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("GET", "/tickets/%s" % uuid.uuid4())
+    with http.ControlClient(srv.config) as c:
+        res = c.get("/tickets/%s" % uuid.uuid4())
         error = res.read()
         assert res.status == http_client.INTERNAL_SERVER_ERROR
         assert b"SECRET" not in error
@@ -124,19 +128,16 @@ def test_general_exception(srv, monkeypatch):
 def test_put_no_ticket_id(srv):
     ticket = testutil.create_ticket()
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/", body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/", body)
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
 
 def test_put_invalid_json(srv):
     ticket = testutil.create_ticket()
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request(
-            "PUT",
-            "/tickets/%(uuid)s" % ticket,
-            "invalid json")
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, "invalid json")
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
@@ -148,8 +149,8 @@ def test_put_mandatory_fields(srv, missing):
     ticket = testutil.create_ticket()
     del ticket[missing.strip("-")]
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
@@ -158,8 +159,8 @@ def test_put_invalid_timeout(srv):
     ticket = testutil.create_ticket()
     ticket["timeout"] = "invalid"
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
@@ -168,8 +169,8 @@ def test_put_url_type_error(srv):
     ticket = testutil.create_ticket()
     ticket["url"] = 1
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
@@ -178,8 +179,8 @@ def test_put_url_scheme_not_supported(srv):
     ticket = testutil.create_ticket()
     ticket["url"] = "notsupported:path"
     body = json.dumps(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PUT", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.put("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 400
         pytest.raises(KeyError, srv.auth.get, ticket["uuid"])
 
@@ -190,8 +191,8 @@ def test_extend(srv, fake_time):
     patch = {"timeout": 300}
     body = json.dumps(patch)
     fake_time.now += 240
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%(uuid)s" % ticket, body)
         ticket["expires"] = int(fake_time.now + ticket["timeout"])
         ticket["active"] = False
         ticket["idle_time"] = 240
@@ -206,8 +207,8 @@ def test_extend_negative_timeout(srv):
     srv.auth.add(ticket)
     patch = {"timeout": -1}
     body = json.dumps(patch)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 400
 
 
@@ -216,8 +217,8 @@ def test_get_expired_ticket(srv, fake_time):
     srv.auth.add(ticket)
     # Make the ticket expire.
     fake_time.now += 500
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("GET", "/tickets/%(uuid)s" % ticket)
+    with http.ControlClient(srv.config) as c:
+        res = c.get("/tickets/%(uuid)s" % ticket)
         assert res.status == 200
 
 
@@ -229,8 +230,8 @@ def test_extend_expired_ticket(srv, fake_time):
     server_ticket = srv.auth.get(ticket["uuid"]).info()
     # Extend the expired ticket.
     body = json.dumps({"timeout": 300})
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%(uuid)s" % ticket, body)
         assert res.status == 200
         server_ticket = srv.auth.get(ticket["uuid"]).info()
         assert server_ticket["expires"] == 800
@@ -241,8 +242,8 @@ def test_extend_no_ticket_id(srv, fake_time):
     srv.auth.add(ticket)
     prev_ticket = srv.auth.get(ticket["uuid"]).info()
     body = json.dumps({"timeout": 300})
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/", body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/", body)
         cur_ticket = srv.auth.get(ticket["uuid"]).info()
         assert res.status == 400
         assert cur_ticket == prev_ticket
@@ -252,8 +253,8 @@ def test_extend_invalid_json(srv, fake_time):
     ticket = testutil.create_ticket()
     srv.auth.add(ticket)
     prev_ticket = srv.auth.get(ticket["uuid"]).info()
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%(uuid)s" % ticket, "{invalid}")
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%(uuid)s" % ticket, "{invalid}")
         cur_ticket = srv.auth.get(ticket["uuid"]).info()
         assert res.status == 400
         assert cur_ticket == prev_ticket
@@ -264,8 +265,8 @@ def test_extend_no_timeout(srv, fake_time):
     srv.auth.add(ticket)
     prev_ticket = srv.auth.get(ticket["uuid"]).info()
     body = json.dumps({"not-a-timeout": 300})
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%(uuid)s" % ticket, body)
         cur_ticket = srv.auth.get(ticket["uuid"]).info()
         assert res.status == 400
         assert cur_ticket == prev_ticket
@@ -276,8 +277,8 @@ def test_extend_invalid_timeout(srv, fake_time):
     srv.auth.add(ticket)
     prev_ticket = srv.auth.get(ticket["uuid"]).info()
     body = json.dumps({"timeout": "invalid"})
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%(uuid)s" % ticket, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%(uuid)s" % ticket, body)
         cur_ticket = srv.auth.get(ticket["uuid"]).info()
         assert res.status == 400
         assert cur_ticket == prev_ticket
@@ -286,8 +287,8 @@ def test_extend_invalid_timeout(srv, fake_time):
 def test_extend_not_found(srv):
     ticket_id = str(uuid.uuid4())
     body = json.dumps({"timeout": 300})
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("PATCH", "/tickets/%s" % ticket_id, body)
+    with http.ControlClient(srv.config) as c:
+        res = c.patch("/tickets/%s" % ticket_id, body)
         assert res.status == 404
 
 
@@ -303,7 +304,7 @@ def test_idle_time_active(srv, fake_time, tmpdir):
 
     # Start a download, but read only 1 byte to make sure the operation becomes
     # active but do not complete.
-    with http.Client(srv.config) as c:
+    with http.RemoteClient(srv.config) as c:
         res = c.get("/images/" + ticket["uuid"])
         res.read(1)
 
@@ -331,7 +332,7 @@ def test_idle_time_put(srv, fake_time, tmpdir):
 
     # Request must reset idle time.
     fake_time.now += 200
-    with http.Client(srv.config) as c:
+    with http.RemoteClient(srv.config) as c:
         c.put("/images/" + ticket["uuid"], "b" * 8192)
         assert srv.auth.get(ticket["uuid"]).idle_time == 0
 
@@ -343,7 +344,7 @@ def test_idle_time_get(srv, fake_time, tmpdir):
 
     # Request must reset idle time.
     fake_time.now += 200
-    with http.Client(srv.config) as c:
+    with http.RemoteClient(srv.config) as c:
         c.get("/images/" + ticket["uuid"])
         assert srv.auth.get(ticket["uuid"]).idle_time == 0
 
@@ -361,7 +362,7 @@ def test_idle_time_patch(srv, fake_time, tmpdir, msg):
     fake_time.now += 200
     body = json.dumps(msg).encode('ascii')
 
-    with http.Client(srv.config) as c:
+    with http.RemoteClient(srv.config) as c:
         c.patch("/images/" + ticket["uuid"], body,
                 headers={"content-type": "application/json"})
         assert srv.auth.get(ticket["uuid"]).idle_time == 0
@@ -373,7 +374,7 @@ def test_idle_time_options(srv, fake_time):
 
     # Request must reset idle time.
     fake_time.now += 200
-    with http.Client(srv.config) as c:
+    with http.RemoteClient(srv.config) as c:
         c.options("/images/" + ticket["uuid"])
         assert srv.auth.get(ticket["uuid"]).idle_time == 0
 
@@ -381,8 +382,8 @@ def test_idle_time_options(srv, fake_time):
 def test_delete_one(srv):
     ticket = testutil.create_ticket()
     srv.auth.add(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("DELETE", "/tickets/%(uuid)s" % ticket)
+    with http.ControlClient(srv.config) as c:
+        res = c.delete("/tickets/%(uuid)s" % ticket)
         assert res.status == 204
         # Note: incorrect according to RFC, but required for vdsm.
         assert res.getheader("content-length") == "0"
@@ -390,8 +391,8 @@ def test_delete_one(srv):
 
 
 def test_delete_one_not_found(srv):
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("DELETE", "/tickets/no-such-ticket")
+    with http.ControlClient(srv.config) as c:
+        res = c.delete("/tickets/no-such-ticket")
         assert res.status == 204
         # Note: incorrect according to RFC, but required for vdsm.
         assert res.getheader("content-length") == "0"
@@ -403,8 +404,8 @@ def test_delete_all(srv):
         ticket = testutil.create_ticket(
             url="file:///tmp/foo%s" % i)
         srv.auth.add(ticket)
-    with http.UnixClient(srv.config.control.socket) as c:
-        res = c.request("DELETE", "/tickets/")
+    with http.ControlClient(srv.config) as c:
+        res = c.delete("/tickets/")
         assert res.status == 204
         # Note: incorrect according to RFC, but required for vdsm.
         assert res.getheader("content-length") == "0"
